<template>
  <a-card :bordered="false">
    <div class="table-page-search-wrapper">
      <a-form layout="inline">
        <a-row :gutter="48">
          <a-col :md="8" :sm="24">
            <a-form-item label="关键字">
              <a-input v-model="queryParam.keyword" placeholder="请输入名称/编码"/>
            </a-form-item>
          </a-col>
          <!--<a-col :md="8" :sm="24">
            <a-form-item label="上层类型">
              <a-tree-select
                style="width: 100%"
                :dropdownStyle="{ maxHeight: '400px', overflow: 'auto' }"
                :treeData="treeData"
                :treeNodeFilterProp="'title'"
                :showSearch="true"
                v-model="queryParam.parentId"
                placeholder="请选择"
              >
              </a-tree-select>
            </a-form-item>
          </a-col>-->
          <a-col :md="8 || 24" :sm="24">
            <span class="table-page-search-submitButtons">
              <a-button type="primary" @click="handleOk">查询</a-button>
              <a-button style="margin-left: 8px" @click="resetSearchForm">重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <div class="table-operator">
      <a-button v-if="$auth('sb-types-add')" type="primary" icon="plus" @click="$refs.baseModal.base()">新增</a-button>
      <a-button style="margin-left: 8px" v-if="$auth('sb-types-export')" type="primary" icon="download" @click="doExport">导出</a-button>
      <a-dropdown v-action:edit v-if="selectedRowKeys.length > 0 && $auth('sb-types-del')">
        <a-menu slot="overlay">
          <a-popconfirm title="是否要删除所选数据？" @confirm="batchDelete()">
            <a-menu-item key="1"><a-icon type="delete" /><a>删除</a></a-menu-item>
          </a-popconfirm>
        </a-menu>
        <a-button style="margin-left: 8px">
          批量操作 <a-icon type="down" />
        </a-button>
      </a-dropdown>
    </div>

    <a-table
      ref="table"
      size="default"
      rowKey="id"
      :columns="columns"
      :data-source="dataSource"
    >
      <span slot="action" slot-scope="record">
        <template>
          <a @click="handleView(record)">查看</a>
          <a-divider type="vertical" />
          <a v-if="$auth('sb-types-edit')" @click="handleEdit(record)">修改</a>
          <a-divider type="vertical" />
          <a-popconfirm v-if="$auth('sb-types-del')" title="是否要删除该条数据？" @confirm="batchDelete(record.id)">
            <a>删除</a>
          </a-popconfirm>
          <a-divider type="vertical" />
          <a @click="handleCopy(record)">复制</a>
        </template>
      </span>
      <span slot="delFlag" slot-scope="text">
        <badge
          :status="DictCache.COLOR.DELFLAG[text]"
          :text="delFlagMap[text]" />
      </span>
    </a-table>
    <base-form ref="baseModal" @ok="handleOk"/>
    <detail ref="detailModal"/>
  </a-card>
</template>

<script>
import { STable, Ellipsis } from '@/components'
import BaseForm from './modules/BaseForm'
import Detail from './modules/Detail'
import { getSbTypePage, deleteSbTypes, fetchSbType, exportSbType, fetchSbTypeTableTree, fetchSbTypeTree } from '@/api/sb/type'

export default {
  name: 'SbTypeList',
  components: {
    STable,
    Ellipsis,
    BaseForm,
    Detail
  },
  data () {
    return {
      // 查询参数
      queryParam: {
      },
      dataSource: [],
      treeData: [],
      typeMap: {},
      delFlagMap: {},
      // 表头
      columns: [
        {
          title: '名称',
          dataIndex: 'name'
        },
        {
          title: '编码',
          dataIndex: 'no'
        },
        {
          title: '首字母',
          dataIndex: 'szm'
        },
        {
          title: '类型',
          dataIndex: 'type',
          customRender: (text, record, index) => {
            return this.BaseTool.Object.getField(this.typeMap, text)
          }
        },
        {
          title: '排序',
          dataIndex: 'sort'
        },
        {
          title: '操作',
          key: 'action',
          width: '200px',
          align: 'center',
          scopedSlots: { customRender: 'action' }
        }
      ],
      // 加载数据方法 必须为 Promise 对象
      loadData: parameter => {
        parameter = {
          ...parameter,
          ...this.queryParam,
          dataScope: {
            sortBy: 'desc',
            sortName: 'update_time'
          }
        }
        return fetchSbTypeTableTree(Object.assign(parameter, this.queryParam))
          .then(res => {
            return res.data
          })
      },
      selectedRowKeys: [],
      selectedRows: [],

      options: {
        alert: { show: true, clear: () => { this.selectedRowKeys = [] } },
        rowSelection: {
          selectedRowKeys: this.selectedRowKeys,
          onChange: this.onSelectChange
        }
      },
      optionAlertShow: false
    }
  },
  created () {
    this.tableOption()
    this.delFlagMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.DELFLAG)
    this.typeMap = this.DictCache.getLabelByValueMapByType(this.DictCache.TYPE.SBTYPE_TYPE)
  },
  methods: {
    tableOption () {
      this.setTree()
      fetchSbTypeTableTree().then(res => {
        this.dataSource = res.data
      })
      if (!this.optionAlertShow) {
        this.options = {
          alert: { show: true, clear: () => { this.selectedRowKeys = [] } },
          rowSelection: {
            selectedRowKeys: this.selectedRowKeys,
            onChange: this.onSelectChange,
            getCheckboxProps: record => ({
              props: {
                disabled: false,
                name: record.id
              }
            })
          }
        }
        this.optionAlertShow = true
      } else {
        this.options = {
          alert: false,
          rowSelection: null
        }
        this.optionAlertShow = false
      }
    },
    batchDelete (id) {
      let ids = []
      if (this.BaseTool.String.isBlank(id)) {
        const length = this.selectedRows.length
        if (length === 0) {
          this.$message.info('请选择要删除的记录')
          return
        }
        ids = this.selectedRows.map(item => item.id)
      } else {
        ids = [id]
      }
      deleteSbTypes(ids).then(res => {
        this.$message.info('删除成功')
        this.handleOk()
        this.$refs.table.clearSelected()
      })
    },
    handleEdit (record) {
      fetchSbType({ id: record.id }).then(res => {
        const modal = this.$refs.baseModal
        modal.base(res.data)
      })
    },
    handleView (record) {
      fetchSbType({ id: record.id }).then(res => {
        const modal = this.$refs.detailModal
        modal.base(res.data)
      })
    },
    handleCopy (record) {
      fetchSbType({ id: record.id }).then(res => {
        const modal = this.$refs.baseModal
        res.data.id = null
        modal.base(res.data)
      })
    },
    handleOk () {
      this.setTree()
      fetchSbTypeTableTree(this.queryParam).then(res => {
        this.dataSource = res.data
      })
    },
    onSelectChange (selectedRowKeys, selectedRows) {
      this.selectedRowKeys = selectedRowKeys
      this.selectedRows = selectedRows
    },
    resetSearchForm () {
      this.queryParam = {
      }
      this.handleOk()
    },
    doExport () {
      const parameter = {
        ...this.queryParam
      }
      exportSbType(parameter).then(file => {
        this.BaseTool.UPLOAD.downLoadExportExcel(file)
      })
    },
    setTree (record = {}) {
      fetchSbTypeTree({ id: record.id }).then((res) => {
        this.treeData = res.data
      })
    }
  }
}
</script>
